==> nextcloud-17.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/text/l10n/el.js <==
OC.L10N.register(
    "text",
    {
    "Text" : "Κείμενο",
    "📝 Collaborative document editing" : "📝 Συνεργατική επεξεργασία εγγράφων",
    "Use current version" : "Χρήση τρέχουσας έκδοσης",
    "Use the saved version" : "Χρήση αποθηκευμένης έκδοσης",
    "The document has been changed outside of the editor. The changes cannot be applied." : "Το έγγραφο έχει αλλάξει εκτός του επεξεργαστή. Οι αλλαγές δεν μπορούν να εφαρμοστούν.",
    "Retry" : "Δοκιμή ξανά",
    "Last save {lastSave}" : "Τελευταία αποθήκευση {lastSave}",
    "Unsaved changes" : "Μη αποθηκευμένες αλλαγές",
    "Enter your name so other users can see who is editing" : "Εισάγετε το όνομά σας ώστε οι άλλοι χρήστες να γνωρίζουν ποιος κάνει επεξεργασία",
    "Edit guest name" : "Επεξεργασία ονόματος επισκέτη",
    "Save guest name" : "Αποθήκευση ονόματος επισκέπτη",
    "Insert image" : "Εισαγωγή εικόνας",
    "Add link" : "Προσθήκη συνδέσμου",
    "Show image" : "Εμφάνιση εικόνας",
    "Show file" : "Εμφάνιση αρχείου",
    "New text document" : "Νέο έγγραφο κειμένου",
    "New text document.md" : "Νέο έγγραφο κειμένου.md",
    "Edit" : "Επεξεργασία",
    "Undo" : "Aναίρεση",
    "Redo" : "Ακύρωση αναίρεσης",
    "Bold" : "Έντονα",
    "Italic" : "Πλάγια",
    "Strikethrough" : "Διαγράμμιση",
    "Paragraph" : "Παράγραφος",
    "Headings" : "Επικεφαλίδες",
    "Heading 1" : "Επικεφαλίδα 1",
    "Heading 2" : "Επικεφαλίδα 2",
    "Heading 3" : "Επικεφαλίδα 3",
    "Heading 4" : "Επικεφαλίδα 4",
    "Heading 5" : "Επικεφαλίδα 5",
    "Heading 6" : "Επικεφαλίδα 6",
    "Unordered list" : "Αταξινόμητη λίστα",
    "Ordered list" : "Ταξινομημένη λίστα",
    "Blockquote" : "Παράθεση",
    "Code block" : "Μπλοκ κώδικα"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/text/l10n/el.js <==
OC.L10N.register(
    "text",
    {
    "Text" : "Κείμενο",
    "📝 Collaborative document editing" : "📝 Συνεργατική επεξεργασία εγγράφων",
    "Use current version" : "Χρήση τρέχουσας έκδοσης",
    "Use the saved version" : "Χρήση αποθηκευμένης έκδοσης",
    "The document has been changed outside of the editor. The changes cannot be applied." : "Το έγγραφο έχει αλλάξει εκτός του επεξεργαστή. Οι αλλαγές δεν μπορούν να εφαρμοστούν.",
    "Retry" : "Δοκιμή ξανά",
    "Last save {lastSave}" : "Τελευταία αποθήκευση {lastSave}",
    "Unsaved changes" : "Μη αποθηκευμένες αλλαγές",
    "Enter your name so other users can see who is editing" : "Εισάγετε το όνομά σας ώστε οι άλλοι χρήστες να γνωρίζουν ποιος κάνει επεξεργασία",
    "Edit guest name" : "Επεξεργασία ονόματος επισκέτη",
    "Save guest name" : "Αποθήκευση ονόματος επισκέπτη",
    "Insert image" : "Εισαγωγή εικόνας",
    "Add link" : "Προσθήκη συνδέσμου",
    "Show image" : "Εμφάνιση εικόνας",
    "Show file" : "Εμφάνιση αρχείου",
    "New text document" : "Νέο έγγραφο κειμένου",
    "Edit" : "Επεξεργασία",
    "Undo" : "Aναίρεση",
    "Redo" : "Ακύρωση αναίρεσης",
    "Bold" : "Έντονα",
    "Italic" : "Πλάγια",
    "Strikethrough" : "Διαγράμμιση",
    "Paragraph" : "Παράγραφος",
    "Headings" : "Επικεφαλίδες",
    "Heading 1" : "Επικεφαλίδα 1",
    "Heading 2" : "Επικεφαλίδα 2",
    "Heading 3" : "Επικεφαλίδα 3",
    "Heading 4" : "Επικεφαλίδα 4",
    "Heading 5" : "Επικεφαλίδα 5",
    "Heading 6" : "Επικεφαλίδα 6",
    "Unordered list" : "Αταξινόμητη λίστα",
    "Ordered list" : "Ταξινομημένη λίστα",
    "Blockquote" : "Παράθεση",
    "Code block" : "Μπλοκ κώδικα",
    "New text document.md" : "Νέο έγγραφο κειμένου.md"
},
"nplurals=2; plural=(n != 1);");
